#!/bin/sh
#Reboot.sh
#version 2.0.0
#by incrys for www.maemomeego.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

reboot=`zenity --question --title CleaN900 --text "Are you sure you want to restart?"; echo $?`

if [ "$reboot" -eq 0 ]
	then
		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Restarting... Please wait..." && `init 6`
	else
		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
fi
